Module lock

Module lock 

File-based locking mechanism for preventing concurrent operations.

This module provides a simple file-based lock using a .lock file to ensure that only one process can operate on a specific resource at a time.

Structs

FileLock
A file-based lock using flock.