Module path

Module path 

Functions

desktop_dir
Returns the desktop directory
home_dir
Returns the user’s home directory
icons_dir
Returns the icons directory
is_safe_component
Returns true if name is a single, normal path component that is safe to join onto a directory.
resolve_path
Resolves a path string that may contain environment variables
xdg_cache_home
Returns the user’s cache directory following XDG Base Directory Specification
xdg_config_home
Returns the user’s config directory following XDG Base Directory Specification
xdg_data_home
Returns the user’s data directory following XDG Base Directory Specification