Skip to main contentModule fs
Source - create_symlink
- Creates symlink from
source to target
If target is a file, it will be removed before creating the symlink. - dir_size
- Calculate the total size in bytes of a directory and all files contained within it.
- ensure_dir_exists
- Creates a directory structure if it doesn’t exist.
- is_elf
- Determine whether the file at the given path is an ELF binary.
- read_file_signature
- Reads the first
bytes bytes from a file and returns the signature. - safe_remove
- Removes the specified file or directory safely.
- walk_dir
- Walks a directory recursively and calls the provided function on each file or directory.